@@ -14,21 +14,6 @@ from docutils.parsers.rst.directives import images
 from sphinx.errors import ExtensionError
 
 
-THUMBNAIL_PARENT_DIV = """
-.. raw:: html
-
-    <div class="sphx-glr-thumbnails">
-
-"""
-
-THUMBNAIL_PARENT_DIV_CLOSE = """
-.. raw:: html
-
-    </div>
-
-"""
-
-
 class MiniGallery(Directive):
     """
     Custom directive to insert a mini-gallery
@@ -87,21 +72,18 @@ class MiniGallery(Directive):
         if not any(has_backrefs(obj) for obj in obj_list):
             return []
 
-        # Add div containing all thumbnails;
-        # this is helpful for controlling grid or flexbox behaviours
-        lines.append(THUMBNAIL_PARENT_DIV)
-
-        # Insert the backreferences file(s) using the `include` directive
+        # Insert the backreferences file(s) using the `include` directive.
+        # This already includes the opening <div class="sphx-glr-thumbnails">
+        # and its closing </div>.
         for obj in obj_list:
             path = os.path.join('/',  # Sphinx treats this as the source dir
                                 backreferences_dir,
                                 '{}.examples'.format(obj))
 
-            # Always remove the heading (first 5 lines) from the file
-            lines.append('.. include:: {}\n    :start-line: 5'.format(path))
-
-        # Close thumbnail parent div
-        lines.append(THUMBNAIL_PARENT_DIV_CLOSE)
+            # Always remove the heading from the file
+            lines.append("""\
+.. include:: {}
+    :start-after: start-sphx-glr-thumbnails""".format(path))
 
         # Parse the assembly of `include` and `raw` directives
         text = '\n'.join(lines)
