@@ -6,12 +6,11 @@ Testing the binder badge functionality
 """
 from __future__ import division, absolute_import, print_function
 
-import os
 from copy import deepcopy
+import os
 
 import pytest
 
-from sphinx_gallery.__init__ import glr_path_static
 from sphinx.errors import ConfigError
 from sphinx_gallery.binder import (gen_binder_url, check_binder_conf,
                                    _copy_binder_reqs, gen_binder_rst)
@@ -31,6 +30,15 @@ def test_binder():
                 'branch?filepath=notebooks/mydir/myfile.ipynb')
     assert url == expected
 
+    # Assert url quoted correctly
+    conf0 = deepcopy(conf_base)
+    special_file_path = "blahblah/mydir/files_&_stuff.py"
+    conf0['branch'] = '100%_tested'
+    url = gen_binder_url(special_file_path, conf0, gallery_conf_base)
+    expected = ('http://test1.com/v2/gh/org/repo/'
+                '100%25_tested?filepath=notebooks/mydir/files_%26_stuff.ipynb')
+    assert url == expected
+
     # Assert filepath prefix is added
     prefix = 'my_prefix/foo'
     conf1 = deepcopy(conf_base)
@@ -93,7 +101,7 @@ def test_binder():
     for iconf in [conf4, conf5]:
         assert iconf == {}
 
-    # Assert extra unkonwn params
+    # Assert extra unknown params
     conf7 = deepcopy(conf1)
     conf7['foo'] = 'blah'
     with pytest.raises(ConfigError, match='Unknown Binder config key'):
@@ -117,19 +125,26 @@ def test_binder():
     assert url == expected
 
 
-def test_gen_binder_rst():
+def test_gen_binder_rst(tmpdir):
     """Check binder rst generated correctly."""
-    gallery_conf_base = {'gallery_dirs': 'mydir', 'src_dir': 'blahblah'}
-    file_path = 'blahblah/mydir/myfile.py'
+    gallery_conf_base = {'gallery_dirs': [str(tmpdir)], 'src_dir': 'blahblah'}
+    file_path = str(tmpdir.join('blahblah', 'mydir', 'myfile.py'))
     conf_base = {'binderhub_url': 'http://test1.com', 'org': 'org',
                  'repo': 'repo', 'branch': 'branch',
                  'dependencies': '../requirements.txt'}
-
-    rst = gen_binder_rst(file_path, conf_base, gallery_conf_base)
-    binder_logo = os.path.join(glr_path_static(), 'binder_badge_logo.svg')
-    binder_logo_path = os.path.relpath(binder_logo, 'blahblah')
-
-    image_rst = (' .. image:: /{}').format(binder_logo_path)
+    conf_base = check_binder_conf(conf_base)
+    orig_dir = os.getcwd()
+    os.chdir(str(tmpdir))
+    try:
+        rst = gen_binder_rst(file_path, conf_base, gallery_conf_base)
+    finally:
+        os.chdir(orig_dir)
+    image_rst = ' .. image:: images/binder_badge_logo.svg'
     target_rst = ':target: http://test1.com/v2/gh/org/repo/branch?filepath=notebooks/mydir/myfile.ipynb'  # noqa E501
+    alt_rst = ':alt: Launch binder'
     assert image_rst in rst
     assert target_rst in rst
+    assert alt_rst in rst
+    image_fname = os.path.join(
+        os.path.dirname(file_path), 'images', 'binder_badge_logo.svg')
+    assert os.path.isfile(image_fname)
