@@ -14,13 +14,15 @@ import os
 import pytest
 import re
 import base64
+import shutil
 import textwrap
 
 from sphinx.errors import ExtensionError
 
 import sphinx_gallery.gen_rst as sg
 from sphinx_gallery.notebook import (rst2md, jupyter_notebook, save_notebook,
-                                     python_to_jupyter_cli)
+                                     promote_jupyter_cell_magic,
+                                     python_to_jupyter_cli,)
 
 
 def test_latex_conversion(gallery_conf):
@@ -40,6 +42,43 @@ def test_latex_conversion(gallery_conf):
     assert align_eq_jmd == rst2md(align_eq, gallery_conf, "", {})
 
 
+def test_code_conversion():
+    """Use the ``` code format so Jupyter syntax highlighting works"""
+    rst = textwrap.dedent("""
+        Regular text
+            .. code-block::
+
+               # Bash code
+
+          More regular text
+        .. code-block:: cpp
+
+          //cpp code
+
+          //more cpp code
+        non-indented code blocks are not valid
+        .. code-block:: cpp
+
+        // not a real code block
+    """)
+    assert rst2md(rst, {}, "", {}) == textwrap.dedent("""
+        Regular text
+        ```
+        # Bash code
+        ```
+          More regular text
+        ```cpp
+        //cpp code
+
+        //more cpp code
+        ```
+        non-indented code blocks are not valid
+        .. code-block:: cpp
+
+        // not a real code block
+    """)
+
+
 def test_convert(gallery_conf):
     """Test ReST conversion"""
     rst = """hello
@@ -64,6 +103,8 @@ For more details on interpolation see the page :ref:`channel_interpolation`.
   :whatever: you
   :width: 200px
   :class: img_class
+
+`See more  <https://en.wikipedia.org/wiki/Interpolation>`_.
 """
 
     markdown = """hello
@@ -78,6 +119,8 @@ This is $some$ math $stuff$.
 For more details on interpolation see the page `channel_interpolation`.
 
 <img src="file://foobar" alt="me" whatever="you" width="200px" class="img_class">
+
+[See more](https://en.wikipedia.org/wiki/Interpolation).
 """  # noqa
     assert rst2md(rst, gallery_conf, "", {}) == markdown
 
@@ -136,12 +179,14 @@ def test_headings():
     ------------------------
     Blank heading above.
 
-                
+    {0}
     ====================
       White space above
     ====================
 
-    """) # noqa
+    """).format('            ')
+    # add whitespace afterward to avoid editors from automatically
+    # removing the whitespace on save
 
     heading_level_counter = count(start=1)
     heading_levels = defaultdict(lambda: next(heading_level_counter))
@@ -163,6 +208,43 @@ def test_headings():
     assert "# White space above\n" in text
 
 
+def test_cell_magic_promotion():
+    markdown = textwrap.dedent("""\
+    # Should be rendered as text
+    ``` bash
+    # This should be rendered as normal
+    ```
+    ``` bash
+    %%bash
+    # bash magic
+    ```
+    ```cpp
+    %%writefile out.cpp
+    // This c++ cell magic will write a file
+    // There should NOT be a text block above this
+    ```
+    Interspersed text block
+    ```javascript
+    %%javascript
+    // Should also be a code block
+    // There should NOT be a trailing text block after this
+    ```
+    """)
+    work_notebook = {"cells": []}
+    promote_jupyter_cell_magic(work_notebook, markdown)
+    cells = work_notebook["cells"]
+
+    assert len(cells) == 5
+    assert cells[0]["cell_type"] == "markdown"
+    assert "``` bash" in cells[0]["source"][0]
+    assert cells[1]["cell_type"] == "code"
+    assert cells[1]["source"][0] == "%%bash\n# bash magic"
+    assert cells[2]["cell_type"] == "code"
+    assert cells[3]["cell_type"] == "markdown"
+    assert cells[3]["source"][0] == "Interspersed text block"
+    assert cells[4]["cell_type"] == "code"
+
+
 @pytest.mark.parametrize(
     'rst_path,md_path,prefix_enabled',
     (('../_static/image.png', 'file://../_static/image.png', False),
@@ -204,9 +286,16 @@ def test_notebook_images_data_uri(gallery_conf):
         gallery_conf['src_dir'], gallery_conf['gallery_dirs'])
 
     test_image = os.path.join(
-        os.path.dirname(__file__), 'tinybuild', '_static', 'demo.png')
+        os.path.dirname(__file__), 'tinybuild',
+        '_static_nonstandard', 'demo.png')
+    # For windows we need to copy this to tmpdir because if tmpdir and this
+    # file are on different drives there is no relpath between them
+    dest_dir = os.path.join(gallery_conf['src_dir'], '_static_nonstandard')
+    os.mkdir(dest_dir)
+    dest_image = os.path.join(dest_dir, 'demo.png')
+    shutil.copyfile(test_image, dest_image)
     # Make into "absolute" path from source directory
-    test_image_rel = os.path.relpath(test_image, gallery_conf['src_dir'])
+    test_image_rel = os.path.relpath(dest_image, gallery_conf['src_dir'])
     test_image_abs = '/' + test_image_rel.replace(os.sep, '/')
     rst = textwrap.dedent("""\
     .. image:: {}
@@ -270,6 +359,18 @@ def test_jupyter_notebook(gallery_conf):
     cell_src = example_nb.get('cells')[-1]['source'][0]
     assert re.match("^Last text block.\n\nThat[\\\\]?'s all folks !", cell_src)
 
+    # Test Jupyter magic code blocks are promoted
+    gallery_conf['promote_jupyter_magic'] = True
+    example_nb = jupyter_notebook(blocks, gallery_conf, target_dir)
+    bash_block = example_nb.get('cells')[-2]
+    assert bash_block['cell_type'] == 'code'
+    assert bash_block['source'][0] == '%%bash\n# This could be run!'
+
+    # Test text above Jupyter magic code blocks is intact
+    md_above_bash_block = example_nb.get('cells')[-3]
+    assert md_above_bash_block['cell_type'] == 'markdown'
+    assert 'Code blocks containing' in md_above_bash_block['source'][0]
+
 
 ###############################################################################
 # Notebook shell utility
